@@ -47,6 +47,34 @@ class OrganizationClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateOrganizationMember(self, request):
+        """创建组织成员
+
+        :param request: Request instance for CreateOrganizationMember.
+        :type request: :class:`tencentcloud.organization.v20210331.models.CreateOrganizationMemberRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.CreateOrganizationMemberResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateOrganizationMember", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateOrganizationMemberResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
