@@ -251,90 +251,6 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeRealtimeNetwork(self, request):
-        """查询sdkappid维度下每分钟实时网络状态，包括上行丢包与下行丢包。可查询24小时内数据，查询起止时间不低于1分钟，不超过1个小时。
-
-        :param request: Request instance for DescribeRealtimeNetwork.
-        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeNetworkRequest`
-        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeNetworkResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeRealtimeNetwork", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeRealtimeNetworkResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeRealtimeQuality(self, request):
-        """查询sdkappid维度下每分钟实时质量数据，包括：进房成功率，首帧秒开率，音频卡顿率，视频卡顿率。可查询24小时内数据，查询起止时间不低于1分钟，不超过1个小时。
-
-        :param request: Request instance for DescribeRealtimeQuality.
-        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeQualityRequest`
-        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeQualityResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeRealtimeQuality", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeRealtimeQualityResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeRealtimeScale(self, request):
-        """查询sdkappid维度下每分钟实时规模，可查询24小时内数据，查询起止时间不低于1分钟，不超过1个小时。
-
-        :param request: Request instance for DescribeRealtimeScale.
-        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeScaleRequest`
-        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeScaleResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeRealtimeScale", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeRealtimeScaleResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DescribeRecordStatistic(self, request):
         """查询云端录制计费时长。
 
